==> json_syntax-0.1.1-py3-none-any.whl: json_syntax/unions.py <==
from .helpers import has_origin, JP, J2P, P2J, IJ, IP, II
from .action_v1 import convert_union, check_union

from functools import partial
from typing import Union


def unions(*, verb, typ, ctx):
    """
    Handle undiscriminated unions of the form ``Union[A, B, C, D]`` by inspecting the
    inner types one by one.

    This is the "implicit discriminant" technique, exploiting the fact that Python
    already tags all values with their type.

    A potential problem is that the JSON structure may not retain that information. So
    another rule could attempt to add a discriminant to the JSON data. For example, if
    you had two ``attrs`` style classes, they could add a `type` field with the class
    name. As there are many ways to do that, this rule doesn't attempt to pick one for
    you.

    Note: The optional rule handles the common case of ``Union[T, NoneType]`` more
    efficiently, so it should be before this.
    """
    if has_origin(typ, Union):
        if verb in JP:
            if verb == P2J:
                check_verb = IP
            elif verb == J2P:
                check_verb = IJ
            else:
                return
            steps = []
            for arg in typ.__args__:
                check = ctx.lookup(verb=check_verb, typ=arg)
                convert = ctx.lookup(verb=verb, typ=arg)
                steps.append((check, convert))
            return partial(convert_union, steps=steps, typename=repr(typ))
        elif verb in II:
            steps = []
            for arg in typ.__args__:
                check = ctx.lookup(verb=verb, typ=arg)
                steps.append(check)
            return partial(check_union, steps=steps)

==> json_syntax-0.2.0a1-py3-none-any.whl: json_syntax/unions.py <==
from .helpers import has_origin, JSON2PY, PY2JSON, INSP_JSON, INSP_PY
from .action_v1 import convert_union, check_union

from functools import partial
from typing import Union


def unions(verb, typ, ctx):
    """
    Handle undiscriminated unions of the form ``Union[A, B, C, D]`` by inspecting the
    inner types one by one.

    This is the "implicit discriminant" technique, exploiting the fact that Python
    already tags all values with their type.

    A potential problem is that the JSON structure may not retain that information. So
    another rule could attempt to add a discriminant to the JSON data. For example, if
    you had two ``attrs`` style classes, they could add a `type` field with the class
    name. As there are many ways to do that, this rule doesn't attempt to pick one for
    you.

    Note: The optional rule handles the common case of ``Union[T, NoneType]`` more
    efficiently, so it should be before this.
    """
    if has_origin(typ, Union):
        if verb in (JSON2PY, PY2JSON):
            if verb == PY2JSON:
                check_verb = INSP_PY
            elif verb == JSON2PY:
                check_verb = INSP_JSON
            else:
                return
            steps = []
            for arg in typ.__args__:
                check = ctx.lookup(verb=check_verb, typ=arg)
                convert = ctx.lookup(verb=verb, typ=arg)
                steps.append((check, convert, "<{!s}>".format(arg)))
            return partial(convert_union, steps=steps, typename=repr(typ))
        elif verb in (INSP_JSON, INSP_PY):
            steps = []
            for arg in typ.__args__:
                check = ctx.lookup(verb=verb, typ=arg)
                steps.append((check, "<{!s}>".format(arg)))
            return partial(check_union, steps=steps)
